@@ -12,6 +12,7 @@ public:
 	bool operator==(const DiveComputerNode &a) const;
 	bool operator!=(const DiveComputerNode &a) const;
 	bool changesValues(const DiveComputerNode &b) const;
+	void showchanges(const QString &n, const QString &s, const QString &f) const;
 	QString model;
 	uint32_t deviceId;
 	QString serialNumber;
@@ -25,7 +26,7 @@ public:
 	~DiveComputerList();
 	const DiveComputerNode *getExact(const QString &m, uint32_t d);
 	const DiveComputerNode *get(const QString &m);
-	void addDC(const QString &m, uint32_t d, const QString &n = QString(), const QString &s = QString(), const QString &f = QString());
+	void addDC(QString m, uint32_t d, QString n = QString(), QString s = QString(), QString f = QString());
 	DiveComputerNode matchDC(const QString &m, uint32_t d);
 	DiveComputerNode matchModel(const QString &m);
 	QMultiMap<QString, DiveComputerNode> dcMap;
