@@ -10,8 +10,12 @@
 #include "subsurfacestartup.h"
 #include "qt-ui/mainwindow.h"
 #include "qt-ui/diveplanner.h"
+#include "qt-ui/graphicsview-common.h"
+#include "qthelper.h"
 
 #include <QStringList>
+#include <QApplication>
+#include <QLoggingCategory>
 #include <git2.h>
 
 QTranslator *qtTranslator, *ssrfTranslator;
@@ -20,8 +24,8 @@ int main(int argc, char **argv)
 {
 	int i;
 	bool no_filenames = true;
-
-	init_qt(&argc, &argv);
+	QLoggingCategory::setFilterRules(QStringLiteral("qt.bluetooth* = true"));
+	QApplication *application = new QApplication(argc, argv);
 	QStringList files;
 	QStringList importedFiles;
 	QStringList arguments = QCoreApplication::arguments();
@@ -30,8 +34,14 @@ int main(int argc, char **argv)
 				 (arguments.at(1) == QString("--win32console"));
 	subsurface_console_init(dedicated_console);
 
+	const char *default_directory = system_default_directory();
+	const char *default_filename = system_default_filename();
+	subsurface_mkdir(default_directory);
+
 	for (i = 1; i < arguments.length(); i++) {
 		QString a = arguments.at(i);
+		if (a.isEmpty())
+			continue;
 		if (a.at(0) == '-') {
 			parse_argument(a.toLocal8Bit().data());
 			continue;
@@ -49,26 +59,38 @@ int main(int argc, char **argv)
 	git_libgit2_init();
 #endif
 	setup_system_prefs();
-	prefs = default_prefs;
+	copy_prefs(&default_prefs, &prefs);
 	fill_profile_color();
 	parse_xml_init();
 	taglist_init_global();
 	init_ui();
 	if (no_filenames) {
-		QString defaultFile(prefs.default_filename);
-		if (!defaultFile.isEmpty())
-			files.push_back(QString(prefs.default_filename));
+		if (prefs.default_file_behavior == LOCAL_DEFAULT_FILE) {
+			QString defaultFile(prefs.default_filename);
+			if (!defaultFile.isEmpty())
+				files.push_back(QString(prefs.default_filename));
+		} else if (prefs.default_file_behavior == CLOUD_DEFAULT_FILE) {
+			QString cloudURL;
+			if (getCloudURL(cloudURL) == 0)
+				files.push_back(cloudURL);
+		}
 	}
-
 	MainWindow *m = MainWindow::instance();
 	m->setLoadedWithFiles(!files.isEmpty() || !importedFiles.isEmpty());
 	m->loadFiles(files);
 	m->importFiles(importedFiles);
+	// in case something has gone wrong make sure we show the error message
+	m->showError();
+
+	if (verbose > 0)
+		print_files();
 	if (!quit)
 		run_ui();
 	exit_ui();
 	taglist_free(g_tag_list);
 	parse_xml_exit();
+	free((void *)default_directory);
+	free((void *)default_filename);
 	subsurface_console_exit();
 	free_prefs();
 	return 0;
