@@ -13,7 +13,8 @@
 
 #include <QTreeView>
 #include <QLineEdit>
-#include "models.h"
+#include <QNetworkAccessManager>
+#include "divetripmodel.h"
 
 class DiveListView : public QTreeView {
 	Q_OBJECT
@@ -48,9 +49,11 @@ slots:
 	void addToTripAbove();
 	void addToTripBelow();
 	void mergeDives();
+	void splitDives();
 	void renumberDives();
 	void shiftTimes();
 	void loadImages();
+	void loadWebImages();
 	static QString lastUsedImageDir();
 
 signals:
@@ -78,6 +81,9 @@ private:
 	void updateLastImageTimeOffset(int offset);
 	int lastImageTimeOffset();
 	void addToTrip(int delta);
+	void matchImagesToDives(QStringList fileNames);
+	void loadImageFromURL(QUrl url);
+	QNetworkAccessManager manager;
 };
 
 #endif // DIVELISTVIEW_H
