@@ -6,16 +6,19 @@
 class QNetworkAccessManager;
 class QNetworkReply;
 
-class UpdateManager : public QObject
-{
+class UpdateManager : public QObject {
 	Q_OBJECT
 public:
 	explicit UpdateManager(QObject *parent = 0);
-	void checkForUpdates();
+	void checkForUpdates(bool automatic = false);
+	static QString getUUID();
+
+public
+slots:
+	void requestReceived();
+
 private:
-	QNetworkAccessManager *manager;
-public slots:
-	void requestReceived(QNetworkReply* reply);
+	bool isAutomaticCheck;
 };
 
 #endif // UPDATEMANAGER_H
