@@ -18,6 +18,12 @@ private slots:
 	void testDecimalParse();
 	void testSpaceDecimalParse();
 	void testDecimalInversedParse();
+	void testXmlFormatParse();
+	void testNoUnitParse();
+	void testNegativeXmlFormatParse();
+	void testPrefixNoUnitParse();
+	void testOurWeb();
+	void testGoogle();
 
 private:
 	static void testParseOK(const QString &txt, double expectedLat,
